# ListBillingAccountCreditBalanceTransactionsResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**credit_balance_transactions** | [**list[CreditBalanceTransaction]**](CreditBalanceTransaction.md) |  | 
**has_more** | **bool** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


